# {{ cookiecutter.name }}: Documentation

The {{ cookiecutter.name }} documentation is split into the following pages:

<!-- TODO nf-core: If you write more documentation pages, add them to the docs index page here -->

* [Usage](usage.md)
  * An overview of how the pipeline works, how to run it and a description of all of the different command-line flags.
* [Output](output.md)
  * An overview of the different results produced by the pipeline and how to interpret them.

You can find a lot more documentation about installing, configuring and running nf-core pipelines on the website: [https://nf-co.re](https://nf-co.re)
